@@ -49,6 +49,7 @@ class ColabGitlabSetup:
         print(f"Loading {self.private_key_file} into an ssh-agent...")
         self.ssh_agent_setup()
         self.ssh_agent_addkey( self.private_key_file )
+        self.ssh_agent_list()
         #self.ssh_agent_kill()
         print("...Loaded")
 
@@ -80,6 +81,10 @@ class ColabGitlabSetup:
         process = subprocess.run( [ 'ssh-add', keyFile ] )
         print(process)
 
+    def ssh_agent_list(self):
+        process = subprocess.run( [ 'ssh-add', "-l" ] )
+        print(process)
+
     def ssh_agent_kill(self):
         process = subprocess.run( [ 'ssh-agent', '-k' ] )
         print(process)
